@@ -1,9 +1,9 @@
 #![deny(anonymous_parameters,
+        coerce_never,
         const_err,
         dead_code,
         deprecated,
         exceeding_bitshifts,
-        extra_requirement_in_impl,
         illegal_floating_point_literal_pattern,
         improper_ctypes,
         invalid_type_param_default,
@@ -33,14 +33,15 @@
         renamed_and_removed_lints,
         resolve_trait_on_defaulted_unit,
         safe_extern_statics,
+        safe_packed_borrows,
         stable_features,
         trivial_numeric_casts,
         unconditional_recursion,
         unions_with_drop_fields,
         unknown_crate_types,
-        unknown_lints,
         unreachable_code,
         unreachable_patterns,
+        unreachable_pub,
         unsafe_code,
         unstable_features,
         unused_allocation,
@@ -61,7 +62,8 @@
         unused_variables,
         while_true)]
 #![warn(unknown_lints)]
-#![allow(box_pointers,
+#![allow(auto_impl,
+        box_pointers,
         missing_debug_implementations,
         trivial_casts,
         unused_results,
